From 95628a2ff3bfc76b94f4c9ebcc30a5c111c89443 Mon Sep 17 00:00:00 2001
From: Amul Sul <amul.sul@enterprisedb.com>
Date: Wed, 14 Dec 2022 11:13:48 +0530
Subject: [PATCH v1 17/25] Change pg_lsn_in to allow non-throw error reporting

---
 src/backend/utils/adt/pg_lsn.c       |  2 +-
 src/test/regress/expected/pg_lsn.out | 13 +++++++++++++
 src/test/regress/sql/pg_lsn.sql      |  4 ++++
 3 files changed, 18 insertions(+), 1 deletion(-)

diff --git a/src/backend/utils/adt/pg_lsn.c b/src/backend/utils/adt/pg_lsn.c
index 15266f36f59..316a102ef30 100644
--- a/src/backend/utils/adt/pg_lsn.c
+++ b/src/backend/utils/adt/pg_lsn.c
@@ -69,7 +69,7 @@ pg_lsn_in(PG_FUNCTION_ARGS)
 
 	result = pg_lsn_in_internal(str, &have_error);
 	if (have_error)
-		ereport(ERROR,
+		ereturn(fcinfo->context, (Datum) 0,
 				(errcode(ERRCODE_INVALID_TEXT_REPRESENTATION),
 				 errmsg("invalid input syntax for type %s: \"%s\"",
 						"pg_lsn", str)));
diff --git a/src/test/regress/expected/pg_lsn.out b/src/test/regress/expected/pg_lsn.out
index 99a748a6a76..e69e0da2c32 100644
--- a/src/test/regress/expected/pg_lsn.out
+++ b/src/test/regress/expected/pg_lsn.out
@@ -255,3 +255,16 @@ SELECT DISTINCT (i || '/' || j)::pg_lsn f
  10/10
 (100 rows)
 
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('16AE7F7', 'pg_lsn');
+ pg_input_is_valid 
+-------------------
+ f
+(1 row)
+
+SELECT pg_input_error_message('16AE7F7', 'pg_lsn');
+             pg_input_error_message              
+-------------------------------------------------
+ invalid input syntax for type pg_lsn: "16AE7F7"
+(1 row)
+
diff --git a/src/test/regress/sql/pg_lsn.sql b/src/test/regress/sql/pg_lsn.sql
index 615368ba960..453ba8ce5d3 100644
--- a/src/test/regress/sql/pg_lsn.sql
+++ b/src/test/regress/sql/pg_lsn.sql
@@ -54,3 +54,7 @@ SELECT DISTINCT (i || '/' || j)::pg_lsn f
        generate_series(1, 5) k
   WHERE i <= 10 AND j > 0 AND j <= 10
   ORDER BY f;
+
+-- test non-error-throwing API for some core types
+SELECT pg_input_is_valid('16AE7F7', 'pg_lsn');
+SELECT pg_input_error_message('16AE7F7', 'pg_lsn');
-- 
2.18.0

